@@ -1,3 +1,53 @@
+# BEGIN BPS TAGGED BLOCK {{{
+# COPYRIGHT:
+# 
+# This software is Copyright (c) 2003-2006 Best Practical Solutions, LLC
+#                                          <clkao@bestpractical.com>
+# 
+# (Except where explicitly superseded by other copyright notices)
+# 
+# 
+# LICENSE:
+# 
+# 
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of either:
+# 
+#   a) Version 2 of the GNU General Public License.  You should have
+#      received a copy of the GNU General Public License along with this
+#      program.  If not, write to the Free Software Foundation, Inc., 51
+#      Franklin Street, Fifth Floor, Boston, MA 02110-1301 or visit
+#      their web page on the internet at
+#      http://www.gnu.org/copyleft/gpl.html.
+# 
+#   b) Version 1 of Perl's "Artistic License".  You should have received
+#      a copy of the Artistic License with this package, in the file
+#      named "ARTISTIC".  The license is also available at
+#      http://opensource.org/licenses/artistic-license.php.
+# 
+# This work is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# General Public License for more details.
+# 
+# CONTRIBUTION SUBMISSION POLICY:
+# 
+# (The following paragraph is not intended to limit the rights granted
+# to you to modify and distribute this software under the terms of the
+# GNU General Public License and is only of importance to you if you
+# choose to contribute your changes and enhancements to the community
+# by submitting them to Best Practical Solutions, LLC.)
+# 
+# By intentionally submitting any modifications, corrections or
+# derivatives to this work, or any other work intended for use with SVK,
+# to Best Practical Solutions, LLC, you confirm that you are the
+# copyright holder for those contributions and you grant Best Practical
+# Solutions, LLC a nonexclusive, worldwide, irrevocable, royalty-free,
+# perpetual, license to use, copy, create derivative works based on
+# those contributions, and sublicense and distribute those contributions
+# and any derivatives thereof.
+# 
+# END BPS TAGGED BLOCK }}}
 package SVK::Notify;
 use SVK::I18N;
 use SVK::Util qw( abs2rel $SEP to_native from_native get_encoding);
@@ -47,6 +97,7 @@ sub print_report {
 		goto \&$print;
 	    };
     return $print_native unless defined $report;
+    $report = "$report";
     from_native($report, 'path', $enc);
     sub {
 	my $path = shift;
@@ -59,12 +110,12 @@ sub print_report {
 	    }
 	}
 	if (length $path) {
-	    $print_native->($is_copath ? SVK::Target->copath ($report, $path)
+	    $print_native->($is_copath ? SVK::Path::Checkout->copath ($report, $path)
 			               : length $report ? "$report/$path" : $path, @_);
 	}
 	else {
 	    my $r = length $report ? $report : '.';
-	    $print_native->($is_copath ? SVK::Target->copath('', $r) : $r,
+	    $print_native->($is_copath ? SVK::Path::Checkout->copath('', $r) : $r,
 			    @_);
 	}
     };
@@ -99,6 +150,7 @@ sub notify_translate {
 
 sub node_status {
     my ($self, $path, $s) = @_;
+    Carp::cluck unless defined $path;
     $self->{status}{$path}[0] = $s if defined $s;
     return exists $self->{status}{$path} ? $self->{status}{$path}[0] : undef;
 }
@@ -157,19 +209,5 @@ sub flush_dir {
     $self->flush ($path, 1);
 }
 
-=head1 AUTHORS
-
-Chia-liang Kao E<lt>clkao@clkao.orgE<gt>
-
-=head1 COPYRIGHT
-
-Copyright 2003-2005 by Chia-liang Kao E<lt>clkao@clkao.orgE<gt>.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
-See L<http://www.perl.com/perl/misc/Artistic.html>
-
-=cut
 
 1;
