@@ -287,14 +287,14 @@ sub _store_config {
 
     if (-f $oldfile ) { 
       rename ( $oldfile => $ancient_backup ) ||
-	die loc("Couldn't remove your old backup configuration file %1 while writing the new one.", $oldfile);
+	die loc("Couldn't remove your old backup configuration file %1 while writing the new one: %2.\n", $oldfile, $!);
     }
     if (-f $file ) {
         rename ($file => $oldfile) ||
-        	die loc("Couldn't remove your old configuration file %1 while writing the new one.", $file);
+        	die loc("Couldn't remove your old configuration file %1 while writing the new one: %2.\n", $file, $!);
     }
     rename ($tmpfile => $file) ||
-	die loc("Couldn't write your new configuration file %1. A backup has been stored in %2. Please replace %1 with %2 immediately.", $file, $tmpfile);
+	die loc("Couldn't write your new configuration file %1. A backup has been stored in %2. Please replace %1 with %2 immediately: %3.\n", $file, $tmpfile, $!);
 
     if (-f $ancient_backup ) {
       unlink ($ancient_backup) ||
@@ -496,7 +496,7 @@ sub find_repos_from_co {
 =item find_repos_from_co_maybe
 
 Like C<find_repos_from_co>, but falls back to see if the given path is
-a depotpath. In that case, the checkout paths returned iwll be undef.
+a depotpath. In that case, the checkout paths returned will be undef.
 
 =cut
 
